@@ -8,7 +8,7 @@ __all__ = [
 colors = Fore
 
 class coloredPrint():
-    def print(textToPrint, color=None):
+    def print(self, textToPrint, color=None):
         if (color == None or not color in colors):
             raise ValueError("Invalid Color")
         print(f"{color}{textToPrint}{colors.RESET}")
